@@ -12,3 +12,5 @@
 #define HAVE_SYS_STAT_H 0
 /* Defined if sys/xattr.h exists */
 #define HAVE_SYS_XATTR_H 1
+/* Defined if has Wayland support */
+#define HAVE_WAYLAND 1
